![sXolar Logo](sxolar.png)

[![PyPI version](https://badge.fury.io/py/sxolar.svg)](https://badge.fury.io/py/sxolar)
![Build](https://github.com/JWKennington/sxolar/actions/workflows/build.yml/badge.svg)
[![CodeFactor](https://www.codefactor.io/repository/github/jwkennington/sxolar/badge)](https://www.codefactor.io/repository/github/jwkennington/sxolar)
[![codecov](https://codecov.io/gh/JWKennington/sxolar/graph/badge.svg?token=s3uaJfzV0q)](https://codecov.io/gh/JWKennington/sxolar)
[![Documentation Status](https://readthedocs.org/projects/sxolar/badge/?version=latest)](https://sxolar.readthedocs.io/en/latest/?badge=latest)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sxolar)
![PyPI - Downloads](https://img.shields.io/pypi/dm/sxolar)
![PyPI - License](https://img.shields.io/pypi/l/sxolar)

# Scholar's tools for working with Arxiv

This repository contains a collection of tools for working with Arxiv. The tools are written in Python and are designed
to be used in any python application. The tools are designed to be used in place of
the [Arxiv API](https://arxiv.org/help/api/index), with a simpler interface and more features, including

- Searching and downloading papers
- Creating personalized search indices for easy repeated searches
- Exploring the network of citations between papers

Ultimately, the goal of this project is to provide a set of tools that can be used to build a personalized search engine
for academic papers, with the ability to search, download, and explore the network of citations between papers.

## Installation

To install the package, you can use pip:

```bash
pip install sxolar
```

## Acknowledgements

Thank you to arXiv for use of its open access interoperability.
